Re-exports
pub use background::*;pub use button::*;pub use form::*;pub use nav::*;pub use size::*;pub use theme::*;pub use container::*;pub use sidebar::*;pub use tab::*;pub use card::*;pub use modal::*;pub use accordion::*;pub use alert::*;pub use badge::*;pub use breadcrumb::*;pub use pagination::*;pub use input::*;pub use dropdown::*;pub use list_group::*;pub use toast::*;pub use utilities::*;
Modules
- accordion
- alert
- background
- This module contains general class selectors defined by the Bootstrap theme. It does not contain any components.
- badge
- breadcrumb
- button
- card
- container
- dropdown
- form
- input
- list_
group - modal
- nav
- pagination
- sidebar
- size
- No components here, just a generic size type used to modify components.
- tab
- theme
- toast
- utilities