Module theme

Module theme 

Structs

GlobalThemeProps
LocalThemeProps

Enums

ThemeMode

Functions

GlobalTheme
Sets dark/light mode based on system setting on the entire html tag. Also loads the required Bootstrap assets from the Bootstrap CDN. If you want to load those assets some other way, you can disable this with the cdn_load_assets prop.
LocalTheme
Overrides the larger mode for child nodes.