Structs
Enums
Functions
- Global
Theme - Sets dark/light mode based on system setting on the entire html tag. Also loads the required Bootstrap assets from the Bootstrap CDN. If you want to load those assets some other way, you can disable this with the cdn_load_assets prop.
- Local
Theme - Overrides the larger mode for child nodes.