GlobalTheme

Function GlobalTheme 

pub fn GlobalTheme(props: GlobalThemeProps) -> Element
Sets dark/light mode based on system setting on the entire html tag. Also loads the required Bootstrap assets from the Bootstrap CDN. If you want to load those assets some other way, you can disable this with the cdn_load_assets prop.